# pmxbot-glossary changelog

**0.3.0**
*(Oct 20, 2014)*

* Added one-way redirects between entries. This adds a new table to the database.
* The commands are currently `redirect` and `unredirect`. 
* Added redirect data to json dump and load.

